#
# spec file for package enchant-1
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   enchant
Name:           enchant-1
Version:        1.6.1
Release:        7.3
Summary:        Generic Spell Checking Library
License:        LGPL-2.1-or-later
Group:          Productivity/Text/Spell
URL:            https://abiword.github.io/enchant/
Source:         https://github.com/AbiWord/enchant/releases/download/enchant-1-6-1/enchant-1.6.1.tar.gz
# PATCH-FIX-UPSTREAM enchant-hunspell-1.4.0.patch dimstar@opensuse.org -- Fix build against hunspell 1.4.0, where WORDMAXLEN is no longer exported
Patch0:         enchant-hunspell-1.4.0.patch
BuildRequires:  dbus-1-glib-devel
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  hunspell-devel
BuildRequires:  libvoikko-devel

%description
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

%package tools
Summary:        Generic Spell Checking Library - Command Line Tools
Group:          Productivity/Text/Spell

%description tools
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

This package provides command-line tools to interact with enchant.

%package data
Summary:        Data files for libenchant
Group:          Productivity/Text/Spell
Conflicts:      enchant-data
# enchant up to version 1.6.1 was not packaged properly according the SLPP
Conflicts:      libenchant1 < 1.6.1
Provides:       libenchant1:%{_datadir}/enchant/enchant.ordering
# Enchant data (and thus the configuration) is provided by all versions of enchant
# Newest one will be installed
Provides:       enchant-data = %{version}

%description data
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

This package provides data/configuration files for libenchant.

%package -n enchant-1-backends
Summary:        ISpell/Myspell backends for libenchant
# enchant up to version 1.6.1 was not packaged properly according the SLPP
Group:          Productivity/Text/Spell
Conflicts:      libenchant1 < 1.6.1
Provides:       enchant-1-backend
Provides:       libenchant1:%{_libdir}/enchant/libenchant_ispell.so

%description -n enchant-1-backends
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

This package provides the ispell and myspell backends.

%package -n enchant-1-backend-voikko
Summary:        Generic Spell Checking Library - Voikko Plugin
Group:          Productivity/Text/Spell
Provides:       enchant-1-backend
Requires:       enchant-1-backends
Provides:       locale(%{name}:fi)
# Package was renamed from enchant-voikko to enchant-1-backend-voikke with version 1.6.1
Obsoletes:      enchant-voikko < 1.6.1

%description -n enchant-1-backend-voikko
Voikko plugin (Finnish) for enchant, a library providing an efficient
extensible abstraction for dealing with different spell checking
libraries.

%package -n enchant-1-backend-zemberek
Summary:        Generic Spell Checking Library - Zemberek Plugin
# Only zemberek-server over D-Bus is supported. Server must be installed locally:
Group:          Productivity/Text/Spell
Recommends:     zemberek-server
Supplements:    packageand(libenchant1:zemberek-server)
Provides:       enchant-1-backend
Provides:       locale(%{name}:az)
Provides:       locale(%{name}:tk)
Provides:       locale(%{name}:tr)
Provides:       locale(%{name}:tt)
# Package was renamed from enchant-voikko to enchant-1-backend-voikke with version 1.6.1
Obsoletes:      enchant-zemberek < 1.6.1

%description -n enchant-1-backend-zemberek
Zemberek plugin (Azeri, Turkmen, Turkish, Tatar) for enchant, a library
providing an efficient extensible abstraction for dealing with
different spell checking libraries.

%package -n libenchant1
Summary:        Generic Spell Checking Library
Group:          System/Libraries
Requires:       enchant-1-backend
Recommends:     enchant-1-backends
Provides:       enchant = %{version}
Obsoletes:      enchant < %{version}

%description -n libenchant1
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glib2-devel
Requires:       libenchant1 = %{version}
Requires:       libstdc++-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%configure --with-pic \
    --disable-static \
    --enable-zemberek \
    --with-myspell-dir=%{_datadir}/myspell

make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libenchant1 -p /sbin/ldconfig
%postun -n libenchant1 -p /sbin/ldconfig

%files tools
%{_bindir}/enchant
%{_bindir}/enchant-lsmod
%{_mandir}/man1/enchant.1%{?ext_man}

%files data
%dir %{_datadir}/enchant
%{_datadir}/enchant/enchant.ordering

%files -n libenchant1
# AUTHORS == MAINTAINERS in 1.3.0, TODO is 1 byte, BUGS has nothing interesting
%license COPYING.LIB
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so.*

%files -n enchant-1-backends
%dir %{_libdir}/enchant
%{_libdir}/enchant/libenchant_ispell.so
%{_libdir}/enchant/libenchant_myspell.so

%files -n enchant-1-backend-voikko
%dir %{_libdir}/enchant
%{_libdir}/enchant/libenchant_voikko.so

%files -n enchant-1-backend-zemberek
%dir %{_libdir}/enchant
%{_libdir}/enchant/libenchant_zemberek.so

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup instead of %%setup/%%patch.
* Tue Dec 20 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Tue Nov 19 2019 Frederic Crozat <fcrozat@suse.com>
- Fix obsoletes/provides in baselibs.conf.
* Tue Nov  5 2019 Frederic Crozat <fcrozat@suse.com>
- Ensure 32bit enchant-1-backends have proper obsoletes/provides
  to upgrade enchant-backends in baselibs.conf.
* Tue Sep 24 2019 Stefan Dirsch <sndirsch@suse.com>
- Make enchant-1-backend-voikko require enchant-1-backends
  (boo#1141993).
* Fri Jul 19 2019 Antonio Larrosa <alarrosa@suse.com>
- Make libenchant1 recommend enchant-1-backends instead of requiring
  any package providing enchant-1-backend. By default, the resolver
  pulls in enchant-1-backend-voikko, which is only valid for the fi
  locale, so by recommending enchant-1-backends, the resolver now
  knows we have a preferred provider for the capability (boo#1141993).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Dec 13 2017 dimstar@opensuse.org
- Update to verssion 1.6.1:
  + This release, the first for several years, is ABI and API
    compatible with 1.6.0, but contains a much-upgraded
    enchant-ispell front-end, which is now a working ispell
    replacement.
  + The code has been cleaned up and some bugs fixed, and the unit
    test suite, originally written 10 years ago for Windows, has
    been made to run on all platforms.
- Update URL to https://abiword.github.io/enchant/.
- Rename to enchant-1: introduce compatibility package, since
  enchant moves to version / API 2.x.
- Adjust packaging to the reworked enchant, following the shared
  library packaging policy and allowing for coexistance of
  enchant-1 and enchant-2 (as foreseen by upstream):
  + Split enchant-1-data package (providing enchant-data, generic
    name) from libenchant1.
  + Split enchant-1-backends from libenchant1: the main backends.
  + Add conflict to libenchant1 < 1.6.1 to the split packages (and
    appropriate split provides).
  + Rename enchant-{voikko,zemberek} to
    enchant-1-backend-{voikko,zemberek}.
* Fri Aug 11 2017 pgajdos@suse.com
- aspell to be removed from factory (bsc#1052949, FATE#323578).
* Mon May  2 2016 dimstar@opensuse.org
- Add enchant-hunspell-1.4.0.patch: Fix build against
  hunspell 1.4.0, where MAXWORDLEN is no longer exported.
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sun Oct  9 2011 alinm.elena@gmail.com
- Pass --with-myspell-dir=%%{_datadir}/myspell to configure as
  myspell dictionaries are there, and not in
  %%{_datadir}/myspell/dicts (default value). Fix bnc#722693.
* Tue Oct  4 2011 vuntz@opensuse.org
- Change zemberek-server Requires in zemberek subpackage to a
  Recommends since we don't have the zemberek-server package in
  Factory; in addition, the plugin uses dbus to communicate with
  the server, and won't fail badly if the server is not there.
- Add a Supplements to zemberek subpackage for
  packageand(libenchant1:zemberek-server), to automatically install
  the zemberek plugin.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Oct 11 2010 vuntz@opensuse.org
- Add enchant-voikko and enchant-zemberek to baselibs.conf.
- Add a Provides for enchant to libenchant1 in baselibs.conf, like
  in the .spec file.
* Wed Aug 25 2010 vuntz@opensuse.org
- Move the files needed by the library to the libenchant1
  subpackage, and create a tools subpackage. The enchant package is
  provided/obsoleted by libenchant1.
* Fri Jun  4 2010 coolo@novell.com
- add baselibs.conf
* Fri Apr  2 2010 vuntz@opensuse.org
- Update to version 1.6.0:
  + Add a function to get enchant's version (enchant_get_version)
  + Disable zemberek plugin by default, as it's known to cause
    issues/crashes with WebKit
  + Fix Win32 DLL dependency not found popup occurs when module has
    unmet dependencies
  + Possibly fix lp#474062
  + Fix Registry handle not closed in enchant_get_registry_value_ex
  + Fix Leak in _enchant_get_user_home_dirs() on Windows
  + Update FSF address
  + Fix Zemberek module listing a Turkish dictionary even without
    Zemberek installed
  + Don't assert if passed a null string list
  + Fix enchant_pwl_init_with_file truncating pwl file
  + Fix a double-free memory corruption bug
  + Fix some small memory leaks
  + Fix mis-acceptence of dictionaries which start with a partial
    match of the lang id
  + Fix enchant always looking in "lib" dir for plugins
  + Fix the build with the MSVC compiler
  + Add a --with-system-myspell option
  + Package missing compile-resource file
  + Compare paths ignoring case sensitivity on windows
- Drop libmalaga-devel BuildRequires.
- Pass --enable-zemberek to configure: it's in a subpackage for us,
  so we can keep it even if it's experimental.
- Explicitly list the backends in the file list to make sure we
  don't lose some of them by accident.
* Sun May 24 2009 vuntz@novell.com
- Update to version 1.5.0 (no NEWS or ChangeLog). Notable changes:
  + Look for myspell/uspell dictionaries in XDG data directories.
  + Various backends now query for any programatically-set
    dictionary paths.
  + Plug memory leaks.
  + Build fixes.
- Remove AutoReqProv: it's default now.
- Do not call autoreconf, there's no need for it.
- Use makeinstall.
* Tue Mar 17 2009 mboman@suse.de
- Don't delete "la" files for distro version <= 11.1
* Fri Mar 13 2009 crrodriguez@suse.de
- remove all "la" files
* Fri Jul 25 2008 sbrabec@suse.cz
- Build with voikko (Finnish, bnc#394355) and zemberek (Azeri,
  Turkmen, Turkish, Tatar) backends.
* Mon May 12 2008 sbrabec@suse.cz
- Updated to version 1.4.2:
  * Improved modularity, support for new modules (not yet in
    openSUSE build: Voikko, Zemberek).
  * System hunspell support improved (bnc#383308).
  * Dictionary search improvements (morphing, affixes, suffixes,
    compound words, phonetic translation table).
  * binreloc support (off in openSUSE)
* Thu Oct 18 2007 sbrabec@suse.cz
- Updated to version 1.3.0:
  * New personal wordlist implementation.
  * Bug and compilation fixes.
- Split according to shared library packaging policy.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Jan  4 2007 sbrabec@suse.cz
- Spec file cleanup.
* Tue Apr 11 2006 jpr@suse.de
- Fix potential infinite loop (#164682)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 sbrabec@suse.cz
- Updated to version 1.2.0.
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Aug  3 2005 sbrabec@suse.cz
- Updated to version 1.1.6.
- Removed unneeded static modules and .la files for modules.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Tue Jan 11 2005 sbrabec@suse.cz
- Updated to version 1.1.5.
* Wed May  5 2004 sbrabec@suse.cz
- Added -fno-strict-aliasing.
* Wed Oct 29 2003 sbrabec@suse.cz
- Updated to version 1.1.1.
* Thu Aug 21 2003 ro@suse.de
- fix build on x86_64
- run autoreconf for full libtool update
* Tue Aug 19 2003 sbrabec@suse.cz
- Initial SuSE version 0.2.0.
